@@ -2,16 +2,25 @@ __author__ = """Jean-Paul Ladage <j.ladage@zestsoftware.nl>"""
 __docformat__ = 'plaintext'
 
 import logging
+
 from zope.i18nmessageid import MessageFactory
 from Products.Archetypes import listTypes
 from Products.Archetypes.atapi import process_types
 from Products.CMFCore import utils as cmfutils
+from Products.validation.exceptions import AlreadyRegisteredValidatorError
+
 from plonehrm.contracts import config
 
 logger = logging.getLogger('plonehrm.contracts')
 logger.debug('Installing Product')
 ContractsMessageFactory = MessageFactory(u'contract')
 
+try:
+    from plonehrm.contracts import validators
+except AlreadyRegisteredValidatorError:
+    pass
+
+
 def initialize(context):
     import content
     from content import tool
