@@ -177,7 +177,7 @@ class Contract(BaseContent):
         if tool is None:
             return []
         else:
-            items = [(item.id, item.Title()) for item in tool.contentValues()]
+            items = [(item.id, item.Title()) for item in tool.listTemplates()]
             return DisplayList(items)
 
     security.declarePublic('template_chosen')
